projectal.entities.permission API documentation

# projectal.entities.permission

View Source

    from projectal.entity import Entity
    from projectal.linkers import *

    class Permission(Entity, UserLinker, AccessPolicyLinker):
        """
        Implementation of the [Permission](https://projectal.com/docs/latest/#tag/Permission) API.
        """
        _path = 'permission'
        _name = 'permission'
        _links_reverse = [UserLinker, AccessPolicyLinker]

class Permission(projectal.entity.Entity, projectal.linkers.UserLinker, projectal.linkers.AccessPolicyLinker):
View Source

    class Permission(Entity, UserLinker, AccessPolicyLinker):
        """
        Implementation of the [Permission](https://projectal.com/docs/latest/#tag/Permission) API.
        """
        _path = 'permission'
        _name = 'permission'
        _links_reverse = [UserLinker, AccessPolicyLinker]

Implementation of the Permission API.

##### Inherited Members

projectal.entity.Entity
  Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  entity_name
projectal.linkers.UserLinker
  link_user
  unlink_user
projectal.linkers.AccessPolicyLinker
  link_access_policy
  unlink_access_policy
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy